local agent_helper = require(AGENT_PATH .. "agent_helper")


function PlatformAdapter:OpenExitDialog()
	agent_helper:Exit(function(result)
		if "true" == result then
			AdapterToLua:endGame()	
		else
			local format = { title = "退出", message = "退出游戏?", positive = "确定", negative = "取消", }
			PlatformAdapter:OpenAlertDialog(format, 
				function (result) 
					if "positive" == result then
						PlatformBinder:JsonCall("call_agent_exit", "true")
						AdapterToLua:endGame()
					end 
				end)
		end
	end)
end

AgentAdapter = {
	is_init = false,
	is_login_verify_ing = false,
	login_callback = nil,
	force_logout = false,
	login_verify_url = "cls.cp01.youyannet.com/ohy/login_verify.php",
	pay_notify_url = "http://cls.cp01.youyannet.com/ohy/pay_callback.php",

	uid = "",
}

-- 初始化
function AgentAdapter:Init()

	if self.is_init then return end
	self.uid = string.gsub((AdapterToLua:getInstance():getDataCache("PRVE_ACCOUNT_NAME") or ""), self:GetSpid() .. "_", "")
	self.is_init = true
	AgentMs:InitLocalPush()
	PlatformBinder:JsonBind("call_agent_logout", function(arg)
		self:LogoutCallback(arg)
		return true
	end)
end

-- 平台ID
function AgentAdapter:GetSpid()
	return "ohy"
end
-- 平台帐号唯一标识
function AgentAdapter:GetOpenId()
	return self.uid
end

-- 加前辍的平台帐号，全平台唯一
function AgentAdapter:GetPlatName()
	return "ohy_" .. self.uid
end

--获得游戏名字
function AgentAdapter:GetGameName()
	return Language.Common.GameName[100]
end

--获得logo资源名
function AgentAdapter:GetLogoResName()
	return "big_logo_txb_ho7"
end

--获得loadingbgname
function AgentAdapter:GetLoadingbgName()
	return "login_bg_txb_ho7"
end


function AgentAdapter:Login(callback)
	if self.is_login_verify_ing then
		SysMsgCtrl.Instance:ErrorRemind("正在登录验证中，请稍等...", true)
		return
	end
	self.login_callback = callback
	agent_helper:Login(LUA_CALLBACK(self, self.LoginCallback))--设置登陆回调 
end

function AgentAdapter:OnClickBackLogin()
	local callback = function()
		AgentLoginView:OnClickBtnLogin()--重新调出登陆界面
    end
    --自己按“返回”切换账号
	PlatformBinder:JsonCall("call_agent_logout", "", "", LUA_CALLBACK(self, callback))
end

function AgentAdapter:LoginCallback(result)--登陆后回调
	print(result)
	local json_obj = cjson.decode(result)	
	
	local user_id = json_obj.uid
	local token = json_obj.token
	local channelCode = json_obj.channelCode
	local productCode = json_obj.productCodes

	local verify_callback = function(url, arg, data, size)
		
		self.is_login_verify_ing = false
		if size <= 0 then
			return
		end
		
		local ret_t = cjson.decode(data)
		if nil == ret_t or 0 ~= ret_t.ret or nil == ret_t.user then
			return
		end
	
		self.uid = ret_t.user.uid
		LoginController.Instance:SetLoginUserData(self:GetPlatName(), ret_t.user)
		self.login_callback(self:GetPlatName())

		agent_helper:ShowFloatButton()
	end


	self.is_login_verify_ing = true
	local now_server_time = math.floor(GLOBAL_CONFIG.server_info.server_time + (Status.NowTime - GLOBAL_CONFIG.client_time))
	local real_url = string.format("%s?spid=%s&userid=%s&token=%s&channelCode=%s&productCode=%s&device=%s", self.login_verify_url, self:GetSpid(), user_id, token, channelCode, productCode, tostring(PlatformAdapter.GetPhoneUniqueId()))
	Log("log_real_url====" .. real_url)
	HttpClient:Request(real_url, "", verify_callback)

	return false
	
end

function AgentAdapter:LogoutCallback(result)--注销回调

	self.uid = ""
	if not LoginController.Instance:AgentLoginViewIsOpen() then
		ReStart()
	end
	return true
end

function AgentAdapter:Pay(role_id, role_name, amount, server_id, callback)--购买
	if self.uid == "" then
		SysMsgCtrl.Instance:ErrorRemind("uid为空，请联系客服")
		return
	end

	local order_id = server_id .. "_" .. self.uid .. "_" .. os.time()
	local param_obj = {}

	param_obj.name = "元宝"
	param_obj.ChargePointName = ""
	param_obj.pay_notify_url = self.pay_notify_url
	param_obj.ext = order_id  --透传参数
	param_obj.amount = amount*100 --分
	param_obj.count = amount*10 --元宝数量

	--Log("param_obj:" .. cjson.encode(param_obj))
	agent_helper:Pay(cjson.encode(param_obj), nil)
end

function AgentAdapter:SubmitRoleData(role_id, role_name, role_level, zone_id, zone_name)
	Log("SubmitRoleData========")
	if RoleData.Instance.role_vo.guild_name == "" then
		RoleData.Instance.role_vo.guild_name = "帮派"
	end
	local info = {}
	info.id = "enterServer"
	info.role_id = role_id
	info.role_name = role_name
	info.role_level = role_level
	info.zone_id = zone_id
	info.zone_name = zone_name
	info.gold = RoleData.Instance.role_vo.gold or 0
	info.guild = RoleData.Instance.role_vo.guild_name or "帮派"
	info.vip = RoleData.Instance.role_vo.vip_level or 0

	self.role_id = role_id
	self.zone_id = zone_id
	self.zone_name = zone_name
	self.role_level = role_level

	PlatformBinder:JsonCall("call_agent_submit_extend_data", cjson.encode(info))
end


function AgentAdapter:ReportOnRoleLevUp(role_id, role_name, role_level, zone_id, zone_name)
	Log("ReportOnRoleLevUp========")
	if RoleData.Instance.role_vo.guild_name == "" then
		RoleData.Instance.role_vo.guild_name = "帮派"
	end
	local info = {}
	info.id = "levelUp"
	info.role_id = role_id
	info.role_name = role_name
	info.role_level = role_level
	info.zone_id = zone_id
	info.zone_name = zone_name
	info.gold = RoleData.Instance.role_vo.gold or 0
	info.guild = RoleData.Instance.role_vo.guild_name or "帮派"
	info.vip = RoleData.Instance.role_vo.vip_level or 0

	self.role_level = role_level

	PlatformBinder:JsonCall("call_agent_submit_extend_data", cjson.encode(info))
end


function AgentAdapter:ReportOnCreateRole(role_name)
	Log("ReportOnCreateRole======================")
	local main_role_vo = GameVoManager.Instance:GetMainRoleVo()
	local user_vo = GameVoManager.Instance:GetUserVo()
	if RoleData.Instance.role_vo.guild_name == "" then
		RoleData.Instance.role_vo.guild_name = "帮派"
	end
	local info = {}
	info.id = "createRole"
	info.role_name = role_name
	info.role_id = main_role_vo.role_id
	info.zone_id = main_role_vo.server_id
	info.zone_name = user_vo.plat_server_id .. "服-" .. user_vo.plat_server_name
	info.gold =  0
	info.guild =  "帮派"
	info.vip =  0
	info.role_level = main_role_vo.level
	print("createRole222222222222222" ..cjson.encode(info))
	PlatformBinder:JsonCall("call_agent_submit_extend_data", cjson.encode(info))
end

--是否支持动态下载
function AgentAdapter:IsDynamicDownloadRes()
	return true
end

-- --是否关闭推送
-- function AgentAdapter:IsClosePush()
-- 	return true
-- end

